@@ -2,8 +2,8 @@
 import sys
 
 from gooey import Gooey, GooeyParser
-from .comFunction import get_list
-from .main_process import  main_process
+from comFunction import get_list
+from main_process import main_process
 
 
 @Gooey(
